Method: Typingpool::Project::Remote#remove_urls

Defined in:
lib/typingpool/project/remote.rb

#remove_urls(urls) ⇒ Object

Like project.remote.remove, except it takes an array of URLs instead an array of remote basenames, saving you from having to manually extract basenames from the URL.



42
43
44
45
# File 'lib/typingpool/project/remote.rb', line 42

def remove_urls(urls)
  basenames = urls.map{|url| url_basename(url) } 
  remove(basenames){|file| yield(file) if block_given? }
end