Class: Typingpool::Config::Root

Inherits:
Config
  • Object
show all
Defined in:
lib/typingpool/config/root.rb

Overview

The root level of the config file and all full config objects. Kept distinct from Config because other subclasses need to inherit from Config, and we don't want them inheriting the root level fields.

Defined Under Namespace

Classes: Amazon, Assign, SFTP